This is a subset of the L-BFGS-B-C code by Stephen Becker available here:

https://github.com/stephenbeckr/L-BFGS-B-C

which is itself based on the L-BFGS-B code by Zhu, Byrd, Nocedal, and Morales,
available here:

http://users.iems.northwestern.edu/~nocedal/lbfgsb.html

and the following references:

* R. H. Byrd, P. Lu and J. Nocedal. A Limited Memory Algorithm for Bound Constrained Optimization, (1995), SIAM Journal on Scientific and Statistical Computing , 16, 5, pp. 1190-1208.
* C. Zhu, R. H. Byrd and J. Nocedal. L-BFGS-B: Algorithm 778: L-BFGS-B, FORTRAN routines for large scale bound constrained optimization (1997), ACM Transactions on Mathematical Software, Vol 23, Num. 4, pp. 550 - 560.
* J.L. Morales and J. Nocedal. L-BFGS-B: Remark on Algorithm 778: L-BFGS-B, FORTRAN routines for large scale bound constrained optimization (2011), ACM Transactions on Mathematical Software, Vol 38, Num. 1.

See LICENSE for the corresponding license.
